# Configure paths for xml, GPLv2
# Markus Fischer <mfischer@josefine.ben.tuwien.ac.at>, 23.9.1999
# URL : http://josefine.ben.tuwien.ac.at/~mfischer/m4/xml.m4
# Last Modified : Thu Sep 23 07:12:32 CEST 1999
# 
# based on xml.m4

dnl AM_PATH_XML([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND [, MODULES]]]])
dnl Test for libxml, and define XML_CFLAGS and XML_LIBS from xml-config
dnl
AC_DEFUN(AM_PATH_XML,
[dnl
dnl Get the cflags and libraries from the xml-config script
dnl
AC_ARG_WITH(xml-prefix,[  --with-xml-prefix=PFX   Prefix where libxml is installed (optional)],
            xml_config_prefix="$withval", xml_config_prefix="")
AC_ARG_WITH(xml-exec-prefix,[  --with-xml-exec-prefix=PFX Exec prefix where libxml is installed (optional)],
            xml_config_exec_prefix="$withval", xml_config_exec_prefix="")
AC_ARG_ENABLE(xmltest, [  --disable-xmltest       Do not try to compile and run a test libxml program],
            , enable_xmltest=yes)

  if test x$xml_config_exec_prefix != x ; then
     if test x${XML_CONFIG+set} != xset ; then
        XML_CONFIG=$xml_config_exec_prefix/bin/xml-config
     fi
  fi
  if test x$xml_config_prefix != x ; then
     if test x${XML_CONFIG+set} != xset ; then
        XML_CONFIG=$xml_config_prefix/bin/xml-config
     fi
  fi

  AC_PATH_PROG(XML_CONFIG, xml-config, no)
  min_xml_version=ifelse([$1], ,1.0.0,$1)
  AC_MSG_CHECKING(for libxml - version >= $min_xml_version)
  no_xml=""
  if test "$XML_CONFIG" = "no" ; then
    no_xml=yes
  else
    XML_CFLAGS=`$XML_CONFIG --cflags`
    XML_LIBS=`$XML_CONFIG --libs`
    xml_config_major_version=`$XML_CONFIG --version | \
           cut -d' ' -f 2 | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    xml_config_minor_version=`$XML_CONFIG --version | \
           cut -d' ' -f 2 | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    xml_config_micro_version=`$XML_CONFIG  --version | \
           cut -d' ' -f 2 | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
    if test "x$enable_xmltest" = "xyes" ; then
      ac_save_CFLAGS="$CFLAGS"
      ac_save_LIBS="$LIBS"
      CFLAGS="$CFLAGS $XML_CFLAGS"
      LIBS="$XML_LIBS $LIBS"
dnl
dnl Now check if the installed XML is sufficiently new. (Also sanity
dnl checks the results of xml-config to some extent
dnl
      rm -f conf.xmltest
      AC_TRY_RUN([
#include <parser.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

int
main ()
{
  int major, minor, micro;
  int xml_major_version, xml_minor_version;
  char *version1,*version2;

  system ("touch conf.xmltest");

  /* HP/UX 9 (%@#!) writes to sscanf strings */
  version1 = strdup("$min_xml_version");
  if (sscanf(version1, "%d.%d.%d", &major, &minor, &micro) != 3) {
     printf("%s, bad supplied version string\n", "$min_xml_version");
     exit(1);
   }

  version2 = strdup(XML_DEFAULT_VERSION);
  if( sscanf(version2,"%d.%d", &xml_major_version, &xml_minor_version) != 2) {
    printf( "%s, bad xml version string\n", XML_DEFAULT_VERSION);
    exit(1);
  }

  if ((xml_major_version != $xml_config_major_version))
    {
      printf("\n*** 'xml-config --version' returned %d.%d.%d, but libxml (%d.%d)\n",
             $xml_config_major_version, $xml_config_minor_version, $xml_config_micro_version,
             xml_major_version, xml_minor_version);
      printf ("*** was found! If xml-config was correct, then it is best\n");
      printf ("*** to remove the old version of libxml. You may also be able to fix the error\n");
      printf("*** by modifying your LD_LIBRARY_PATH enviroment variable, or by editing\n");
      printf("*** /etc/ld.so.conf. Make sure you have run ldconfig if that is\n");
      printf("*** required on your system.\n");
      printf("*** If xml-config was wrong, set the environment variable XML_CONFIG\n");
      printf("*** to point to the correct copy of xml-config, and remove the file config.cache\n");
      printf("*** before re-running configure\n");
    }
  else if ((xml_major_version != major) ||
           (xml_minor_version != minor))
    {
      printf("*** libxml header files (version %d.%d) do not match\n",
         major, minor);
      printf("*** library (version %d.%d)\n",
         xml_major_version, xml_minor_version);
    }
  else
    {
      if ((xml_major_version > major) ||
        ((xml_major_version == major) && (xml_minor_version >= minor)))
      {
        return 0;
       }
     else
      {
        printf("\n*** An old version of libxml (%d.%d) was found.\n",
               xml_major_version, xml_minor_version);
        printf("*** You need a version of libxml newer than %d.%d.%d. The latest version of\n",
           major, minor, micro);
        printf("*** libxml is always available from ftp://ftp.gnu.org/gnu/xml/ .\n");
        printf("***\n");
        printf("*** If you have already installed a sufficiently new version, this error\n");
        printf("*** probably means that the wrong copy of the xml-config shell script is\n");
        printf("*** being found. The easiest way to fix this is to remove the old version\n");
        printf("*** of libxml, but you can also set the XML_CONFIG environment to point to the\n");
        printf("*** correct copy of xml-config. (In this case, you will have to\n");
        printf("*** modify your LD_LIBRARY_PATH enviroment variable, or edit /etc/ld.so.conf\n");
        printf("*** so that the correct libraries are found at run-time))\n");
      }
    }
  return 1;
}
],, no_xml=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
     fi
  fi
  if test "x$no_xml" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$2], , :, [$2])
  else
     AC_MSG_RESULT(no)
     if test "$XML_CONFIG" = "no" ; then
       echo "*** The xml-config script installed by libxml could not be found"
       echo "*** If libxml was installed in PREFIX, make sure PREFIX/bin is in"
       echo "*** your path, or set the XML_CONFIG environment variable to the"
       echo "*** full path to xml-config."
     else
       if test -f conf.xmltest ; then
        :
       else
          echo "*** Could not run libxml test program, checking why..."
          CFLAGS="$CFLAGS $XML_CFLAGS"
          LIBS="$LIBS $XML_LIBS"
          AC_TRY_LINK([
#include <parser.h>
],      [ return ; ],
        [ echo "*** The test program compiled, but did not run. This usually means"
          echo "*** that the run-time linker is not finding libxml or finding the wrong"
          echo "*** version of libxml. If it is not finding libxml, you'll need to set your"
          echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
          echo "*** to the installed location  Also, make sure you have run ldconfig if that"
          echo "*** is required on your system"
          echo "***"
          echo "*** If you have an old version installed, it is best to remove it, although"
          echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH"
          echo "***"],
        [ echo "*** The test program failed to compile or link. See the file config.log for the"
          echo "*** exact error that occured. This usually means libxml was incorrectly"
          echo "*** installed or that you have moved libxml since it was installed. In the"
          echo "*** latter case, you may want to edit the xml-config script:"
          echo "*** $XML_CONFIG" ])
          CFLAGS="$ac_save_CFLAGS"
          LIBS="$ac_save_LIBS"
       fi
     fi
     XML_CFLAGS=""
     XML_LIBS=""
     ifelse([$3], , :, [$3])
  fi
  AC_SUBST(XML_CFLAGS)
  AC_SUBST(XML_LIBS)
  rm -f conf.xmltest
])
